@@ -1,6 +1,6 @@
 import json
 import snappi
-from trex.stl.api import *
+import trex.stl.api as trex
 from snappi_trex.validation import Validation
 from snappi_trex.setconfig import SetConfig
 from snappi_trex.capture import Capture
@@ -35,7 +35,7 @@ class Api(snappi.Api):
             sync_port = int(parse_loc[1])
                 
         super(Api, self).__init__()
-        self._c = STLClient(server=server,
+        self._c = trex.STLClient(server=server,
                             sync_port=sync_port
         )
 
@@ -106,11 +106,11 @@ class Api(snappi.Api):
             vmCmds += SetConfig.fix_checksum(layers)
 
             # Construct the packet with given Flow Variables
-            vm = STLScVmRaw(vmCmds)
-            pkt = STLPktBuilder(pkt = pkt_base/pad, vm = vm)
+            vm = trex.STLScVmRaw(vmCmds)
+            pkt = trex.STLPktBuilder(pkt = pkt_base/pad, vm = vm)
 
             # Create the stream with given config
-            s1 = STLStream(packet = pkt,
+            s1 = trex.STLStream(packet = pkt,
                         mode = mode)
 
             # Add the stream to the client
